import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import css from '../node_modules/shiki/dist/langs/css.js';
import html from '../node_modules/shiki/dist/langs/html.js';
import javascript from '../node_modules/shiki/dist/langs/javascript.js';
import json from '../node_modules/shiki/dist/langs/json.js';
import markdown from '../node_modules/shiki/dist/langs/markdown.js';
import php from '../node_modules/shiki/dist/langs/php.js';
import tsx from '../node_modules/shiki/dist/langs/tsx.js';
import typescript from '../node_modules/shiki/dist/langs/typescript.js';

var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
function log(message, ...args) {
  {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
const LANGS = {
  typescript,
  javascript,
  json,
  html,
  css,
  markdown,
  tsx,
  php,
  // Add a plaintext fallback
  plaintext: {
    id: "plaintext",
    scopeName: "source.plaintext",
    grammar: {
      patterns: [{ match: ".*", name: "text.plain" }]
    }
  }
};
let highlighterInstance = null;
function getHighlighter() {
  return __async(this, null, function* () {
    if (highlighterInstance) {
      log("Returning cached highlighter instance");
      return highlighterInstance;
    }
    try {
      log("Creating new highlighter instance...");
      log("Initializing JavaScript regex engine...");
      const engine = createJavaScriptRegexEngine();
      log("Engine created successfully");
      log("Loading language definitions...");
      const languageDefinitions = Object.values(LANGS);
      log(`Prepared ${languageDefinitions.length} language definitions`);
      log("Creating highlighter core...");
      highlighterInstance = yield createHighlighterCore({
        langs: languageDefinitions,
        engine
      });
      log("Highlighter core created successfully");
      return highlighterInstance;
    } catch (error) {
      log("Error creating highlighter:", error);
      throw new Error(`Failed to initialize syntax highlighter: ${error instanceof Error ? error.message : "Unknown error"}`);
    }
  });
}

export { LANGS, getHighlighter };
//# sourceMappingURL=SyntaxContext.js.map
